pub fn reject(reason: &str) -> ControlMessageExpand description
Refuse a connection before it is attached to anything.
REF: references/vendored/Mumble.proto : Reject.RejectType.
pub fn reject(reason: &str) -> ControlMessageRefuse a connection before it is attached to anything.
REF: references/vendored/Mumble.proto : Reject.RejectType.